pub mod base64;
pub mod beep;
pub mod calc;
pub mod chess;
pub mod clear;
pub mod colors;
pub mod copy;
pub mod date;
pub mod delete;
pub mod dhcp;
pub mod disk;
pub mod editor;
pub mod elf;
pub mod env;
pub mod find;
pub mod geotime;
pub mod halt;
pub mod help;
pub mod hex;
pub mod host;
pub mod http;
pub mod httpd;
pub mod install;
pub mod keyboard;
pub mod lisp;
pub mod list;
pub mod memory;
pub mod net;
pub mod pci;
pub mod pow;
pub mod print;
pub mod r#move;
pub mod read;
pub mod shell;
pub mod sleep;
pub mod tcp;
pub mod uptime;
pub mod user;
pub mod vga;
pub mod write;
